@@ -15,6 +15,18 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
+"""
+Fastkml is a library to read, write and manipulate kml files. It aims to keep
+it simple and fast (using lxml if available). Fast refers to the time you spend
+to write and read KML files as well as the time you spend to get aquainted to
+the library or to create KML objects. It provides a subset of KML and is aimed
+at documents that can be read from multiple clients such as openlayers and
+google maps rather than to give you all functionality that KML on google earth
+provides.
+"""
+
+from pkg_resources import get_distribution, DistributionNotFound
+
 from .kml import KML, Document, Folder, Placemark
 from .kml import TimeSpan, TimeStamp
 from .kml import ExtendedData, Data
@@ -26,7 +38,10 @@ from .styles import LabelStyle, BalloonStyle
 
 from .atom import Link, Author, Contributor
 
-__version__ = '0.9'
+try:
+    __version__ = get_distribution('fastkml').version
+except DistributionNotFound:
+    __version__ = 'dev'
 
 __all__ = [
     'KML', 'Document', 'Folder', 'Placemark',
