@@ -144,7 +144,8 @@ class StyleMap(_StyleSelector):
 
     def __init__(self, ns=None, id=None, normal=None, highlight=None):
         super(StyleMap, self).__init__(ns, id)
-        pass
+        self.normal = normal
+        self.highlight = highlight
 
     def from_element(self, element):
         super(StyleMap, self).from_element(element)
@@ -353,10 +354,10 @@ class PolyStyle(_ColorStyle):
         super(PolyStyle, self).from_element(element)
         fill = element.find('%sfill' % self.ns)
         if fill is not None:
-            self.fill = int(fill.text)
+            self.fill = int(float(fill.text))
         outline = element.find('%soutline' % self.ns)
         if outline is not None:
-            self.outline = int(outline.text)
+            self.outline = int(float(outline.text))
 
 
 class LabelStyle(_ColorStyle):
